==> vector_vault-1.0.1.tar.gz: vector_vault-1.0.1/vectorvault/creds.py <==
# VECTOR VAULT CONFIDENTIAL
# __________________
# 
#  All Rights Reserved.
# 
# NOTICE:  All information contained herein is, and remains
# the property of Vector Vault and its suppliers,
# if any.  The intellectual and technical concepts contained
# herein are proprietary to Vector Vault
# and its suppliers and may be covered by U.S. and Foreign Patents,
# patents in process, and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material
# is strictly forbidden unless prior written permission is obtained
# from Vector Vault.

from google.auth.credentials import Credentials
import requests
import datetime

class CustomCredentials(Credentials):
    def __init__(self, user, api):
        self.user = user
        self.api = api
        self.token = None
        self.expiry = None
        self.refresh()

    def apply(self, headers, token=None):
        headers["Authorization"] = f"Bearer {self.token}"

    @property
    def valid(self):
        if self.expiry is None:
            return False
        return datetime.datetime.now() < self.expiry

    def refresh(self):
        if not self.valid:
            data = {
                "user_id": self.user,
                "api_key": self.api,
            }
            response = requests.post('https://vv-creds-etrszydrna-uc.a.run.app/access', json=data)
            response.raise_for_status()  
            response_data = response.json()
            self.token = response_data['access_token']
            self.expiry = datetime.datetime.fromisoformat(response_data['expiry'])

    def before_request(self, headers):
        self.apply(headers)

    def __getstate__(self):
        return self.__dict__.copy()

    def __setstate__(self, state):
        self.__dict__.update(state)

==> vector_vault-1.1.0.tar.gz: vector_vault-1.1.0/vectorvault/creds.py <==
# VECTOR VAULT CONFIDENTIAL
# __________________
# 
#  All Rights Reserved.
# 
# NOTICE:  All information contained herein is, and remains
# the property of Vector Vault and its suppliers,
# if any.  The intellectual and technical concepts contained
# herein are proprietary to Vector Vault
# and its suppliers and may be covered by U.S. and Foreign Patents,
# patents in process, and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material
# is strictly forbidden unless prior written permission is obtained
# from Vector Vault.

from google.auth.credentials import Credentials
import requests
import datetime

class CustomCredentials(Credentials):
    def __init__(self, user, api):
        self.user = user
        self.api = api
        self.token = None
        self.expiry = None
        self.refresh()

    def apply(self, headers, token=None):
        headers["Authorization"] = f"Bearer {self.token}"

    @property
    def valid(self):
        if self.expiry is None:
            return False
        return datetime.datetime.now() < self.expiry

    def refresh(self):
        if not self.valid:
            data = {
                "user_id": self.user,
                "api_key": self.api,
            }
            response = requests.post('https://vv-creds-etrszydrna-uc.a.run.app/access', json=data)
            response.raise_for_status()  
            response_data = response.json()
            self.token = response_data['access_token']
            self.expiry = datetime.datetime.fromisoformat(response_data['expiry'])

    def before_request(self, auth_request, method, url, request_headers):
        self.apply(request_headers)

    def __getstate__(self):
        return self.__dict__.copy()

    def __setstate__(self, state):
        self.__dict__.update(state)
